pub enum CompressorType {
None = 0,
PointWise = 1,
PointWiseChunked = 2,
LayeredChunked = 3,
}Expand description
The possibilities for how the compressed data is organized.
Variants
None = 0
PointWise = 1
No chunks, or rather only 1 chunk with all the points
PointWiseChunked = 2
Compress points into chunks with chunk_size points in each chunks
LayeredChunked = 3
Compress points into chunk, but also separate the different point dimension / fields into layers. This CompressorType is only use for point 6,7,8,9,10